/* $Workfile: OtxDmp.h $   $Revision: 4 $    $Modtime: 6/17/09 6:27a $  */
#ifndef OTX_DMP_H
#define OTX_DMP_H
/*******************************************************************************

  @doc PublicHwApi OtxDmp

  Copyright (C) 2007 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxDmp | This file contains prototypes for the Digital Media Processor (DMP) Management Functions

  @contents2
  OtxDmp.h |

  @index func | OtxDmp

  @contents2
  OTX DMP Device Management Functions - OtxDmpXXX() | The user functions available for
  the Management of GPP ARM Devices

  @head3 OtxDmpXXX() Function Reference |

  @index func | OtxDmp

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions
#include "OtxDef.h"     // OTX specific definitions

#include "OtxDmpD.h"    // OTX DMP type definitions

#ifdef __cplusplus
extern "C" {
#endif



/*******************************************************************************

  @func
    Boot the DMP from a selected source (Flash memory or UART). The normal boot
    source would be Flash memory. The UART boot source is mainly used to load the 
    bootloader (u-boot) into the Flash memory during the debugging and development
    phase.

    If the UART boot option is used then the serial port of the DMP must be connected
    to a COM port of a PC, which is running a terminal emulation program like HyperTerm 
    or putty. The serial port should be configured for a 115200 baudrate, 
    8 data bits, 1 stop bit, and no parity. 

    Under normal operating conditions (when u-boot is already stored in the Flash memory)
    the boot source would be Flash.
    

  @ex |

    // open physical device of DMP 
                  hBoardController, // Vidar series or Thor-8-PCI-Plus series 
                  OTX_DEVICE_DMP, 
                  0, 
                  0, 
                  g_hEventQueue, 
                  &hDmp[i]); 
    
    // Normal boot operation. Boot from the NAND Flash memory.
    result = OtxDmpBoot(hDmp, OTX_DMP_BOOT_FLASH);

  @xref
    <f OtxDmpRunStandardProgramModule>
    <f OtxDmpRunCodecEngineServer>
    <f OtxDmpRestartCodecEngineServer>
********************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpBoot(
  IN OTX_HANDLE         hDmpDevice,         // @parm Handle to DMP device
  IN OtxDmpBootSourceE  eBootSource         // @parm Boot from this boot source
);




/*******************************************************************************

  @func
    Load and Run a Codec Engine Server on a ARM from a formatted program file

  @ex |

    // open physical device of DMP 
    for (i = 0; i < 2; i++) {
      result = OtxDrvOpenPhysicalDevice(
                  g_hPhysDevs.hBoardController, // Vidar series or Thor-8-PCI-Plus series 
                  OTX_DEVICE_DMP, 
                  i, 
                  i, 
                  g_hEventQueue, 
                  &g_hPhysDevs.hDmp[i]); 
    }
    
    // load DMP program from file OtxSpm1.img
    for (nDmp = 0; nDmp < 2; nDmp++) {
      result = OtxDmpRunCodecEngineServer(
                  g_hPhysDevs.hDmp[nDmp], 
                  "OtxSpm1.tgz", 
                  "otx.ce.spm1"); 
    }

  @xref
    <f OtxDmpRunStandardProgramModule>
    <f OtxDmpRestartProgram>
********************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRunCodecEngineServer(
  IN OTX_HANDLE     hDmpDevice,         // @parm Handle to DMP device
  IN const char     *szPrgfile,         // @parm Application file to be loaded
  IN const char     *szEntryPoint       // @parm Label for the entry point of the application
);


/*******************************************************************************

  @func
    Load and Run an OTX Standard Program Module (SPM) on a DMP from the a 
    program image stored in the OTX lib.
  
  @ex |
  
    // open physical device of DMP 
    for (i = 0; i < 2; i++) {
      result = OtxDrvOpenPhysicalDevice(
                  g_hPhysDevs.hBoardController, // Vidar series or Thor-2-PCMCIA series 
                  OTX_DEVICE_DMP, 
                  i, 
                  i, 
                  g_hEventQueue, 
                  &g_hPhysDevs.hDmp[i]); 
    }
  
  
    // load DMP Program OTX_DMP_SPM_OTXSPM1
    for (i = 0; i < 2; i++) {
      result = OtxDmpRunStandardProgramModule(
                  g_hPhysDevs.hDmp[i], 
                  OTX_DMP_SPM_OTXSPM1); 
    }

  @xref
    <f OtxDmpRunImage>
    <t OtxDmpSpmE>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRunStandardProgramModule(
  IN OTX_HANDLE     hDmpDevice,         // @parm Handle to DMP device
  IN OtxDmpSpmE     eProgramModule      // @parm Standard Program Module (SPM) to be loaded in the DMP (from the Lib)
);

/*******************************************************************************

  @func
    Load and start a DMP application program. The DMP application program must 
    be in the OTX DMP Image format (created by a call 
    to <f OtxDmpCreateProgramImage>). 

  @ex |
    see example on       
    @ex <f OtxDmpCreateProgramImage> |
    @ex <f OtxDmpCreateProgramImageEx> |

  @xref
    <f OtxDmpCreateProgramImage>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRunImage(
  IN OTX_HANDLE  hDmpDevice,      // @parm Handle to DMP device
  IN OTX_UINT8  *psqProgImage,    // @parm Program image 
  IN OTX_UINT32  coProgImage,     // @parm Number of elements in psqProgImage 
  IN OTX_INT32   runAddr          // @parm Program Entry Address 
);


/*******************************************************************************

  @func
    Load and start a DMP application program. The DMP application program must 
    be in the OTX DMP Image format (created by a call 
    to <f OtxDmpCreateProgramImage>). 

  @ex |
    see example on       
    @ex <f OtxDmpCreateProgramImage> |

  @xref
    <f OtxDmpCreateProgramImage>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRunCodecEngineServerImage(
  IN OTX_HANDLE     hDmpDevice,         // @parm Handle to DMP device
  IN OTX_UINT16     *psqProgImage,      // @parm Program image 
  IN OTX_UINT16     coProgImage,        // @parm Number of elements in psqProgImage 
  IN OTX_INT32      nEntryAddr          // @parm Program Entry Address 
);


/*******************************************************************************

  @func
    DMP Debugging utility function. Restarts a previously loaded and/or 
    running program. 
    
    This function is only meant to be called if a DMP Debugger is being
    used. 

  @ex |

    // load DMP program
    for (nDmp = 0; nDmp < 2; nDmp++) {
      result = OtxDmpRunSpmCodecEngineServer(
                  g_hPhysDevs.hDmp[nDmp], 
                  OTX_DMP_SPM_OTXSPM1); 
    }

    // load and run DMP program to all of the DMPs in the DMP Debugger

    // restart program on DMPs
    for (i = 0; i < 2; i++) {
        result = OtxDmpRestartCES(g_hPhysDevs.hDmp[i]); 
    }

  @xref
    <f OtxDmpRunProgram>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRestartCodecEngineServer(
  IN OTX_HANDLE     hDmpDevice          // @parm Handle to DMP device
);



/*******************************************************************************

  @func
    Transfer a file from the host system to the DMP device.

  @xref
    <f OtxDmpDownloadFile>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpUploadFile(
  IN  OTX_HANDLE    hDmpDevice,         // @parm Handle to the physical DMP device
  IN  char         *szSendFileName,      // @parm File name on the host system to be transmitted
  IN  char         *szTargetPath         // @parm Target DMP filesystem path
                                        //       i.e "/root/myfile
);

/*******************************************************************************

  @func
    Transfer a file from the DMP device to the host system.

  @xref
    <f OtxDmpUploadFile>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpDownloadFile(
  IN  OTX_HANDLE    hDmpDevice,         // @parm Handle to the physical DMP device
  IN  char         *szReceiveFileName,  // @parm File name to be received to be placed on the host filesystem
  IN  char         *szTargetPath        // @parm Target DMP filesystem path
                                        //       i.e "/root/myfile"
);

/*******************************************************************************

  @func
    Set the network parameters (e.g. IP address, subnet mask etc) for ethernet port
    of the DMP device.

  @xref
    <f OtxDmpGetNetworkParams>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpSetNetworkParams(
  IN  OTX_HANDLE     hDmpDevice,         // @parm Handle to the physical DMP device
  IN  OTX_UINT8     *sqMacAddress,       // @parm MAC Address of DMP. Provide a NULL parameter to leave the MAC address unchanged. 6 bytes. Example 00:50:C2:81:70:0B. sqMacAddress[5] is the 0x00 byte (MSB) and sqMacAddress[0] is the 0x0B byte (LSB)
  IN  OTX_UINT8     *sqIpAddress,        // @parm IP Address of DMP Ethernet port. 4 bytes. Example 10.0.1.103. sqIpAddress[3] is the 10 byte (MSB) and sqIpAddress[0] is the 103 byte (LSB)
  IN  OTX_UINT8     *sqSubnetMask        // @parm Subnet mask of DMP Ethernet port. 4 bytes. Example 10.0.1.200. sqSubnetMask[3] is the 255 byte (MSB) and sqSubnetMask[0] is the 0 byte (LSB)
);

/*******************************************************************************

  @func
    Retrieve the network parameters (e.g. IP address, subnet mask etc) for ethernet port
    of the DMP device.

  @xref
    <f OtxDmpSetNetworkParams>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpGetNetworkParams(
  IN  OTX_HANDLE    hDmpDevice,         // @parm Handle to the physical DMP device
  OUT OTX_UINT8    *sqMacAddress,       // @parm MAC Address of DMP. 6 bytes. Example 00:50:C2:81:70:0B. sqMacAddress[5] is the 0x00 byte (MSB) and sqMacAddress[0] is the 0x0B byte (LSB)
  OUT OTX_UINT8    *sqIpAddress,        // @parm IP Address of DMP Ethernet port. 4 bytes. Example 10.0.1.103. sqIpAddress[3] is the 10 byte (MSB) and sqIpAddress[0] is the 103 byte (LSB)
  OUT OTX_UINT8    *sqSubnetMask        // @parm Subnet mask of DMP Ethernet port. 4 bytes. Example 10.0.1.200. sqSubnetMask[3] is the 255 byte (MSB) and sqSubnetMask[0] is the 0 byte (LSB)
);


/*******************************************************************************

  @func
    Run a separate, stand-alone process in the ARM core of the DMP device.

  @xref
    <f OtxDmpKillStandaloneProcess>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpRunStandaloneProcess(
  IN  OTX_HANDLE    hDmpDevice,         // @parm Handle to the physical DMP device
  IN  char         *szProcessName,      // @parm Process file name with the path  on the target filesystem
  OUT OTX_UINT32   *pnProcessId         // @parm Target system Process PID
);

/*******************************************************************************

  @func
    Kill a specific stand-alone process in the ARM core of the DMP device.

  @xref
    <f OtxDmpRunStandaloneProcess>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpKillStandaloneProcess(
  IN  OTX_HANDLE    hDmpDevice,         // @parm Handle to the physical DMP device
  IN  char         *szProcessName,      // @parm Process file name with the path  on the target filesystem
  IN  OTX_UINT32    nProcessId,         // @parm Target DMP filesystem PID
  IN  OTX_BOOL      bKillAll            // @parm Kill all processes with the same name (PID=0 this case)
);


/*******************************************************************************

  @func
    Internal function

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpServePacket(
  IN OTX_HANDLE   hDmpDevice,
  IN OTX_UINT8   *pPacket,
  IN OTX_UINT32   cbPacket
);

/*******************************************************************************
  @func
    For internal use.
*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxDmpReadPacket(
  IN  OTX_HANDLE  hDmpDevice,
  OUT OTX_UINT8   *pPacket,
  IN  OTX_UINT32  nBufLen,
  OUT OTX_UINT32  *pcbPacket
);


#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2007

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif    // OTX_DMP_H
